:
# NAME:
#	config_setup.sh - initialize system config process
#
# DESCRIPTION:
#	This module is mainly responsible for initializing the
#	"DIR_LIST" which is searched for file lists and files to be
#	installed.  We look for the following directories and if
#	present, we add them to "DIR_LIST".   Also each directory in
#	"BIN_PATH" and "SHAREBIN_PATH" that exists under each of these
#	is added to "PATH" so that the install process can use
#	programs not yet installed.  Obviously "BIN_PATH" dirs are
#	only added if "DEST_OS" and "OS" are compatible.
#	
#.nf
#
#	"CONFIGS"/"SITE"/"OS"/"OSREL"/"MACHINE"
#	"CONFIGS"/"SITE"/"OS"/"OSREL"/"MACHINE_ARCH"
#	"CONFIGS"/"SITE"/"OS"/"OSREL"
#	"CONFIGS"/"OS"/"OSREL"/"MACHINE"
#	"CONFIGS"/"OS"/"OSREL"/"MACHINE_ARCH"
#	"CONFIGS"/"OS"/"OSREL"
#	"CONFIGS"/"SITE"/"OS"/"OSMAJOR".X/"MACHINE"
#	"CONFIGS"/"SITE"/"OS"/"OSMAJOR".X/"MACHINE_ARCH"
#	"CONFIGS"/"SITE"/"OS"/"OSMAJOR".X
#	"CONFIGS"/"OS"/"OSMAJOR".X/"MACHINE"
#	"CONFIGS"/"OS"/"OSMAJOR".X/"MACHINE_ARCH"
#	"CONFIGS"/"OS"/"OSMAJOR".X
#	"CONFIGS"/"SITE"/"OS"/"MACHINE"
#	"CONFIGS"/"SITE"/"OS"/"MACHINE_ARCH"
#	"CONFIGS"/"SITE"/"OS"
#	"CONFIGS"/"OS"/"MACHINE"
#	"CONFIGS"/"OS"/"MACHINE_ARCH"
#	"CONFIGS"/"OS"
#	"CONFIGS"/"SITE"
#	"CONFIGS"
#	
#	Where:
#.fi
#
#	"CONFIGS"
#		is the top level config directory (it must exist :-).
#
#	"SITE"	identifies a site.  The default is "FQDN_SITE" which
#		is the domain in reverse and upper case.  For example
#		zen.crufty.net gives NET/CRUFTY.  If the domain
#		name cannot be determined the old default of ``local''
#		is used. 
#		The "SITE" variable can be initialized in the
#		environment or by adding an ``S01site.sh'' to
#		config.d.  Note that "SITE" can contain several
#		components and each one will be used first with
#		"CONFIG_INIT" (normally empty, see below) appended and
#		then by itself in turn. 
#		For example "SITE"=``Org/Site/Sub Alt/Site''
#		would result in each pattern above involving "SITE" to
#		be repeated for each of Org/Site/Sub/"CONFIG_INIT",
#		Org/Site/Sub, Org/Site/"CONFIG_INIT", Org/Site,
#		Org/"CONFIG_INIT", Org, Alt/Site/"CONFIG_INIT",
#		Alt/Site, and Alt/"CONFIG_INIT", Alt. 
#
#	"OS"	is the operating system running on "HOST"
#		(uname -s).
#
#	"MACHINE"
#		is "HOST"s hardware (uname -m). When building
#		"DIR_LIST" we split this at any ``.'' or ``/'' into
#		separate dirs, so for a HP 9000/720, we look for
#		9000/720 and 9000.
#
#	"MACHINE_ARCH"
#		Only used if different from "MACHINE".	Some systems
#		have an 'arch' command which returns a value different
#		to 'uname -m'.	For example: All Sun Sparc systems
#		(sun4c, sun4m, sun4u) all have an "MACHINE_ARCH" of sun4.
#		Thus for systems that run on multiple architectures,
#		kernels and other "MACHINE" specific files can be 
#		placed in "OS"/"OSREL"/"MACHINE" while binaries that
#		will run on all "MACHINE"s with the same
#		"MACHINE_ARCH" can be placed in
#		"OS"/"OSREL"/"MACHINE_ARCH" or even
#		"OS"/"OSMAJOR"/"MACHINE_ARCH". 
#
#	"OSREL"	is the operating system release (uname -r).
#
#	"OSMAJOR"
#		is the major release of "OS".  When building
#		"DIR_LIST" we actually split "OSREL" at each ``.'' or
#		``/'' so for SunOS 4.1.4 we look for directories named
#		4.1.X and 4.X.
#
#	"HOSTNAME"
#		is hopfully the fully qualified domain name of the
#		host.  "HOST" is the first component of "HOSTNAME".
#	
#	Actually we use the variables "HOST", "HOSTNAME", "OS", "OSREL",
#	"MACHINE" and "MACHINE_ARCH" for the host running the script,
#	but build "DIR_LIST" for "DEST_HOST", "DEST_OS", "DEST_OSREL",
#	"DEST_MACHINE" and "DEST_MACHINE_ARCH" which may be different if
#	updating hosts via NFS.  "DEST_HOSTNAME" defaults to
#	"HOSTNAME" only if "DEST_HOST" is the same as "HOST",
#	otherwise it defaults to "DEST_HOST".
#
#	We also define "DEST_HOST_TARGET" which is the "DEST_" form of
#	"HOST_TARGET" which is set by /etc/rc_d/os.sh and takes the
#	form ${OS}${OSMAJOR}-${MACHINE_ARCH} all converted to lower case.
#
#	"CONFIG_INIT":
#	
#	If the directory "DESTDIR"/etc/rc_d does not exist, then we
#	assume that this is the first time that 'config.sh' has been
#	run and we set "CONFIG_INT" to ``init'' (unless already set), and
#	"OLD_EXT" (used by 'install_files' to save old files and
#	normally set to .old) to .FCS, so the originals will not be
#	lost by future invocations.
#
#	Use of "CONFIG_INIT" allows certain actions to be performed
#	once only.  For example, /etc/passwd, shadow and group files
#	might be installed under "SITE"/init/"OS"/"OSMAJOR".X/etc to
#	ensure that new machines have a working set of accounts with
#	passwords set, without the risk of continually replacing them.
#
#	"SITE_SETUP_SH":
#
#	The initial "DIR_LIST" is searched for a "SITE_SETUP_SH"
#	(default is none) and if found it is sourced at that point.
#	
#	"CLASS":
#
#	The initial "DIR_LIST" is next searched for directories named
#	for the elements in "DEST_CLASS", which can be thought of as
#	aliases for "DEST_HOST" and always includes "CONFIG_INIT", the
#	last component of "SITE" and the content of any
#	config_class.list files found by searching "DIR_LIST".
#	Next we search for directories named "DEST_HOST" and
#	"DEST_HOSTNAME" and prepend these to the "DIR_LIST", then
#	repeat "CONFIG_INIT" again so that any
#	"DEST_HOST"*/"CONFIG_INIT" will be used.
#
#	Finally, we again check for
#	"DEST_OS"/"DEST_OSREL"/"DEST_MACHINE" etc so that any such
#	directories under a "DEST_HOST" directory will take precedence
#	over any other.  This allows host specific binaries to be kept
#	under the appropriate "DEST_OS" sub-tree so that the right
#	things will happen if the host is ever re-built on a different
#	platform.
#
#	Actually lists are searched for using "REV_LIST" which is
#	"DIR_LIST" in reverse.	Thus generic lists are installed
#	before specific ones.  This allows the specific lists to more
#	easily override the generic ones.
#
#	MD5:
#
#	We search "DIR_LIST" for files called 'MD5.OUT' or 'MD5.list'
#	which are expected to contain MD5 checksums of files below
#	that point in the config tree.	We concatenate these files
#	(editing them in the process to reflect the actual location of
#	the files from the executing hosts perspective) to a local
#	filesystem (/tmp by default), and use the resulting list when
#	checksuming files in the config tree.
#
#	This approach saves considerable I/O when the tree is
#	mounted via NFS.  The script md5s.pl(1) can be run regularly
#	to keep the 'MD5.list' files up to date.
#
# SEE ALSO:
#	configs(8), install_files(8), remove_files(8), set_perms(8),
#	md5s.pl(1), update_file(8), update_host(8).
#
# BUGS:
#	The order that directories are searched for adding to
#	"DIR_LIST" attempts to minimize the need to replicate config
#	data.  For example, all SunOS/4.1.4 directories will be added
#	before any SunOS/4.1.X before SunOS/4.X and so on.  Just to
#	keep it exciting though, "SITE"/SunOS/4.1.4/sun4m and
#	"SITE"/SunOS/4.1.4  will both be added before
#	SunOS/4.1.4/sun4m.
#
#	If the 'MD5.list' files are out of date, then the affected
#	files will be updated everytime the script is run.
#	
# AUTHOR:
#	Simon J. Gerraty <sjg@crufty.net>
#
#	

# RCSid:
#	$Id: config_setup.sh,v 1.79 2004/04/15 23:58:16 sjg Exp $
#
#	@(#) Copyright (c) 1995 Simon J. Gerraty
#
#	This file is provided in the hope that it will
#	be of use.  There is absolutely NO WARRANTY.
#	Permission to copy, redistribute or otherwise
#	use this file is hereby granted provided that 
#	the above copyright notice and this notice are
#	left intact. 
#      
#	Please send copies of changes and bug-fixes to:
#	sjg@crufty.net
#

# we don't want ksh or a posix sh wasting time...
ENV=
Mydir=${Mydir:-`dirname $0`}

_SOURCE_SH=:

source() {
	f=$1; shift

	for d in ${*:-`IFS=:; echo $PATH`}
	do
		test -s $d/$f && { . $d/$f; break; }
	done
}

case "$_shell" in
"")	# not run via rc.sh
	source /etc/rc_d/funcs.sh $CONFIGS $Mydir/.. ""
	;;
esac

CONFIGS=${CONFIGS-`cd $Mydir/..; pwd`}
ECHO="echo $Myname:"

source /etc/rc_d/debug.sh $CONFIGS ""

DebugOn setup config_setup

source /etc/rc_d/mktemp.sh $Mydir/.. $CONFIGS ""
source /etc/rc_d/temp.sh $Mydir/.. $CONFIGS ""

$_OS_SH source /etc/rc_d/os.sh $CONFIGS ""
source /etc/rc_d/fqdn.sh $CONFIGS ""

# we actually care that this is a qualified name
case "$HOSTNAME" in
""|*.*) ;;
*)	x=`fqdn $HOSTNAME`
        x=${x:-`fqdn $HOSTNAME.`}
        HOSTNAME=${x:-$HOSTNAME}
        ;;
esac
        
# we twiddle to show that we are busy...
TWDL=${TWDL:-:}
test "$TWDL" = twdl && echo $N "Initializing$C"
$TWDL

# these allow us to update a different OS/MACHINE via NFS
DEST_HOST=${DEST_HOST:-$HOST}
DEST_OS=${DEST_OS:-$OS}
DEST_OSREL=${DEST_OSREL:-$OSREL}
DEST_MACHINE=${DEST_MACHINE:-$MACHINE}

#
# some hosts have arch which may not match machine...
# eg, sun4[cmu] all have MACHINE_ARCH=sun4
# so we can put kernels in $OS/$OSREL/$MACHINE
# and misc binaries in $OS/$OSMAJOR/$MACHINE_ARCH
#
DEST_MACHINE_ARCH=${DEST_MACHINE_ARCH:-$MACHINE_ARCH}
DEST_MACHINE_ARCH=${DEST_MACHINE_ARCH:-$DEST_MACHINE}
DEST_OSMAJOR=`IFS=.; set $DEST_OSREL; echo $1`
dest_host_target=${DEST_HOST_TARGET:-`echo ${DEST_OS}${DEST_OSMAJOR}-${DEST_MACHINE_ARCH} | tr 'A-Z' 'a-z'`}

# enforce what we want for some known cases, and
# otherwise default to something very generic
case "$OS/$MACHINE_ARCH" in
NetBSD*)	SHARE_ARCH=$OS/$MACHINE_ARCH;;
*sun386)	SHARE_ARCH=$MACHINE_ARCH;;
SunOS*)		SHARE_ARCH=$OS/$OSMAJOR.X/$MACHINE_ARCH;;
esac
SHARE_ARCH=${SHARE_ARCH:-$OS/$OSMAJOR.X/$MACHINE_ARCH}
case "$DEST_OS/$DEST_MACHINE_ARCH" in
NetBSD*)	DEST_SHARE_ARCH=$DEST_OS/$DEST_MACHINE_ARCH;;
*sun386)	DEST_SHARE_ARCH=$DEST_MACHINE_ARCH;;
SunOS*)		DEST_SHARE_ARCH=$DEST_OS/$DEST_OSMAJOR.X/$DEST_MACHINE_ARCH;;
HP-UX*)		DEST_OSMAJOR=`IFS=.; set $DEST_OSREL; echo $2`;;
esac
DEST_SHARE_ARCH=${DEST_SHARE_ARCH:-$DEST_OS/$DEST_OSMAJOR.X/$DEST_MACHINE_ARCH}
DEST_HOST_TARGET=${DEST_HOST_TARGET:-$dest_host_target}

export DEST_HOST_TARGET

DIR_LIST=
REV_LIST=

# we build a string of the FQDN reversed to use as a default SITE.
FQDN_SITE=`$CONFIGS/bin/fqdn_site`
case "$FQDN_SITE" in
*/*)	SITE_CLASS="${SITE_CLASS:-`basename ./$FQDN_SITE`}"
	;;
esac

# remove the "local" symlink if using FQDN_SITE
SITE=${SITE:-$FQDN_SITE:local}
case "$SITE" in
*local) ;;
*)	SITE_CLASS="${SITE_CLASS:-`basename ./$SITE`}";;
esac


# if DEST_HOSTNAME is not set and DEST_HOST == HOST,
# use HOSTNAME otherwise just make it same as DEST_HOST
# we wait until now, so that we can still use ${DEST_HOSTNAME:-$HOSTNAME}
# above when setting FQDN_SITE
case $DEST_HOST in
$HOST)	DEST_HOSTNAME=${DEST_HOSTNAME:-$HOSTNAME};;
*)	DEST_HOSTNAME=${DEST_HOSTNAME:-$DEST_HOST};;
esac

#
# if /etc/rc_d does not exist, then this is first time in
# and we want to look for $CONFIG_INIT under each dir in $DIR_LIST as well.
# and use .FCS as our $OLD_EXT
#
[ -d $DESTDIR/etc/rc_d ] || { CONFIG_INIT=${CONFIG_INIT:-init}; OLD_EXT=${OLD_EXT:-FCS}; }
#
# These are the directories under each config top dir,
# that we will add to PATH if they exist
#
BIN_PATH=${BIN_PATH:-"/sbin:/bin:/usr/sbin:/usr/bin:/usr/ucb:/usr/5bin:/usr/local/bin"}
SHAREBIN_PATH=${SHAREBIN_PATH:-"/share/bin:/usr/local/share/bin"}

#
# If $1 exists add it to DIR_LIST
# Then add any of $BIN_PATH that exist under $1, to PATH
#
add_dir() {
	if [ -d $1 ]
	then
		case " $DIR_LIST $dir_list " in
		*" $1 "*) ;;
		*)
			DIR_LIST="$DIR_LIST $1"
			REV_LIST="$1 $REV_LIST"

			#
			# this lets us use things not yet installed.
			#
			if [ "$SHARE_ARCH" = "$DEST_SHARE_ARCH" ]; then
				for sd in `IFS=" :"; echo $BIN_PATH:$SHAREBIN_PATH`
				do
					$TWDL
					[ -d $1$sd ] || continue
					PATH=$PATH:$1$sd
				done
			else
				for sd in `IFS=" :"; echo $SHAREBIN_PATH`
				do
					$TWDL
					[ -d $1$sd ] || continue
					PATH=$PATH:$1$sd
				done
			fi
			;;
		esac
	fi
}


#
# The following looks a big ugly, but it allows SITE to be something
# like Org/Site/sub and we will use each of Org/Site/sub Org/Site and
# Org to look for the directories in OS_DIRS.
#
# At present we also look for HOST in each component of SITE, this
# could be risky if you have multiple machines with the same name.
# Of course we could use a fully qualified domain name...
#
# These are the directories we search and in the given order.
# The directories are ordered from most to least specific.
# Thus configs/Void/zen/netbsd would be installed in favour of
# configs/NetBSD/1.0A/i386/netbsd
#
# The directories other than $OS under $CONFIGS/$SITE and $CONFIGS
# should contain only machine independent files.
#

# This function is a generic form of the old dir_list and what we used
# to do for OSREL under NetBSD -current.
# It takes a variable and returns a list of dirs to look for.
# Eg `var2dirs . 4.1.4 . .X` returns /4.1.4 /4.1.X and /4.X
# and `var2dirs / Void/init` returns /Void/init /Void
# We put the leading '/' in here so that we can tack a "" to the end
# when we use the list.

# we use drop_last() in rc.sh
var2dirs() {
	sep=$1
	var=$2
	joint=${3:-$1}
	trailer=$4
	
	DL=/$var

	while :
	do
		DL="$DL /$var$trailer"
		var=`drop_last $sep $var $joint`
		case "$var" in
		"")	break;;
		esac
	done
	echo $DL
}

. $CONFIGS/config.d/config_listfuncs.sh

DebugOn machine_dirs
# Many OS's have versions like 1.2A 1.2D 1.2G, we want them all
# to look in 1.2.X so insert a '.' bewteeb any digit an letter.
xosrel=`echo $DEST_OSREL | sed 's/\([0-9]\)\([A-Za-z_-]\)/\1.\2/g'`
OSREL_DIRS=`var2dirs ./ $xosrel . .X | sed 's,\.-,-,g'`
MACHINE_DIRS=`var2dirs ./ $DEST_MACHINE /`
if [ "$DEST_MACHINE_ARCH" != "$DEST_MACHINE" ]; then
	MACHINE_DIRS="$MACHINE_DIRS `var2dirs ./ $DEST_MACHINE_ARCH /`"
fi
# backwards compat hook, for SunOS, treat sun4 as alias for sparc
case "$DEST_OS:$DEST_MACHINE_ARCH" in
SunOS:sparc)
        MACHINE_DIRS="$MACHINE_DIRS /sun4"
        ;;
esac
$DEBUG_DO echo MACHINE_DIRS="$MACHINE_DIRS"
DebugOff machine_dirs

SITE_DIRS=

for site_dir in `IFS=": "; echo $SITE`
do
	SITE_DIRS="$SITE_DIRS`var2dirs / $site_dir` "
done

# build DIR_LIST without any host dirs...
# we want all 4.1.4 dirs before 4.1.X dirs.
for o_d in $OSREL_DIRS ""
do
	for top in $SITE_DIRS ""
	do
		for m_d in $MACHINE_DIRS ""
		do
			add_dir $CONFIGS$top${CONFIG_INIT:+/}$CONFIG_INIT/$DEST_OS$o_d$m_d
			add_dir $CONFIGS$top/$DEST_OS$o_d$m_d
		done
	done
done

# these should be generic stuff only
for top in $SITE_DIRS ""
do
	case "$top" in
	""|/*)	;;
	*)	top=/$top;;
	esac
	add_dir $CONFIGS$top${CONFIG_INIT:+/}$CONFIG_INIT
	add_dir $CONFIGS$top
done
[ -d $CONFIGS/bin ] && PATH=$PATH:$CONFIGS/bin

# at this point we can search our initial DIR_LIST for $SITE_SETUP_SH
# if set and source it if found
if [ "$SITE_SETUP_SH" ]; then
        x=`find_file $SITE_SETUP_SH`
        [ "$x" ] && . $x
fi
# now scan $DIR_LIST looking for class dirs 
# and put them at the front...
# note that we look for $DEST_HOST/config_class.list so we can find it
# before DEST_HOST is in DIR_LIST
dest_class=
for c in `_build_list $DEST_HOST/config_class.list $DEST_HOSTNAME/config_class.list config_class.list; IFS=" :,"; echo ${DEST_CLASS:-$CLASS} $SITE_CLASS`
do
	case " $dest_class " in
	*" $c "*) ;;
	*)	dest_class="$dest_class $c";;
	esac
done
DEST_CLASS="$dest_class"

add_classes() {
	[ "$*" ] || return
	dir_list="$DIR_LIST"
	rev_list="$REV_LIST"
	DIR_LIST=
	REV_LIST=
	for d in $dir_list
	do
		for c in $*
		do
			add_dir $d/$c
		done
	done
	DIR_LIST="$DIR_LIST $dir_list"
	REV_LIST="$rev_list $REV_LIST"
}

$TWDL
add_classes $CONFIG_INIT
$TWDL
add_classes $DEST_CLASS
$TWDL
# we do DEST_HOST last so it ends up at the head of the list
add_classes $DEST_HOST
[ $DEST_HOST = $DEST_HOSTNAME ] || add_classes $DEST_HOSTNAME
$TWDL
# Ok, getting silly now.  See if we have $OSREL_DIRS under $DEST_HOST*
# this is actually handy since it allows us to put host specific binaries
# under the correct OS/REL/MACHINE/path sub-directory so that if we
# ever re-build the host on a different platform the right things will
# happen.
for o_d in $OSREL_DIRS
do
	for m_d in $MACHINE_DIRS ""
	do
		add_classes $DEST_OS$o_d$m_d
	done
	$TWDL
done
$TWDL
add_classes $CONFIG_INIT
$TWDL

# Allow these to be controlled independent of DESTDIR
PATH_ETC_PASSWD=${PATH_ETC_PASSWD:-$DESTDIR/etc/passwd}
PATH_ETC_GROUP=${PATH_ETC_GROUP:-$DESTDIR/etc/group}
export PATH_ETC_PASSWD PATH_ETC_GROUP

if [ -s $PATH_ETC_GROUP ]; then
	eval `grep -i '^[a-z][a-z0-9]*:' $PATH_ETC_GROUP | cut -d: -f1,3 | sed -e 's/\(.*\):\(.*\)/g_\1=\2; export g_\1;/'`
fi

[ -t 0 ] && TTY=`tty` || TTY=

OS_DIR=${OS_DIR:-`echo $OS$OSMAJOR | tr '[A-Z]' '[a-z]'`}
DEST_OS_DIR=${DEST_OS_DIR:-`echo $DEST_OS$DEST_OSMAJOR | tr '[A-Z]' '[a-z]'`}

$TWDL

# we put out own patches in a Patches dir.
PATCHES="$PATCHES `find_all /Patches -d`"
PATCHES="$PATCHES `find_file /Patches/Recommended -d`"
PATCHES="$PATCHES `find_file /Patches/Y2K -d`"

PKGADD_OPTS=
export PKGADD_OPTS

case "$SHARE_ARCH" in
HP-UX*)
	test -x /usr/bin/bdf && DF=/usr/bin/bdf
	;;
SunOS/5*)
	PKGADD_OPTS="-n -S"
	a=`find_file /pkgadd_admin`
	a=${a:-$Mydir/pkgadd_admin}
	[ -s $a ] && PKGADD_OPTS="$PKGADD_OPTS -a $a"
	# look for a local cdrom,
	# then for an NFS mounted cdrom
	for d in /cdrom/patches*/files	`find_file /patches/files -d`
	do
		[ -d $d ] && PATCHES="$PATCHES $d"
	done
	df_k=-k
	DF="df -k"
	;;
esac

case "$DF" in
"")
	case `df -k / 2>&1 > /dev/null` in
	"")	df_k=-k;;
	esac
	;;
esac

DU=${DU:-"du $df_k -s"}
DF=${DF:-"df $df_k"}

# some systems have a broken or otherwise limited find.
# so see if we can find gnu find (as gfind).
FIND=`Which gfind`
FIND=${FIND:-find}
# this is much better if available.
# see spacefor(1)
SPACEFOR=${SPACEFOR:-`Which spacefor`}
SPACEFOR=${SPACEFOR:-space_for}

MD5_LIST=$TMP/MD5_LIST
REBOOT_LIST=$TMP/REBOOT
CHANGE_LIST=$TMP/CONFIG_CHANGES
INSTALL_LIST=$TMP/install_files.list.$HOST

$TWDL

# look for any MD5.list files and use them...
for d in $DIR_LIST
do
	for f in MD5.list MD5.OUT
	do
		[ -s $d/$f ] && sed "s,(\.*/*,($d/," $d/$f
	done
	$TWDL
done | sort -u > $MD5_LIST

if [ -s $MD5_LIST ]; then
	md5list="MD5_LIST=$MD5_LIST, "
fi

#
# see if ch{own,grp} support -h, we trust that every
#
tf=$TMP/tf$$
touch $tf
case "`${CHOWN:-chown} -h 0 $tf 2>&1`" in
"")	chown_h=-h; export chown_h;;
esac
case "`${CHGRP:-chgrp} -h 0 $tf 2>&1`" in
"")	chgrp_h=-h; export chgrp_h;;
esac

export CONFIGS DIR_LIST PATH BIN_PATH SITE DF DU TTY OS_DIR PATCHES FIND MD5_LIST CHANGE_LIST REBOOT_LIST INSTALL_LIST REV_LIST TMP
export DEST_HOST DEST_HOSTNAME DEST_OS DEST_OSREL DEST_OSMAJOR DEST_MACHINE DEST_MACHINE_ARCH SHARE_ARCH DEST_SHARE_ARCH OLD_EXT SPACEFOR

$TWDL " "
echo
echo $N "Using: CONFIGS=$CONFIGS, SITE=$SITE, DEST_HOST=$DEST_HOST DEST_HOSTNAME=$DEST_HOSTNAME TMP=$TMP, $md5list$C"
echo "PATCHES=$PATCHES, DESTDIR=$DESTDIR, DIR_LIST=$DIR_LIST" | sed -e 's,=  *,=,g' -e "s,$CONFIGS/,,g"

DebugOff setup config_setup
